==> apache-juneau-8.2.0-src.zip: juneau-8.2.0/juneau-doc/src/main/java/org/apache/juneau/doc/internal/Console.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.doc.internal;

import java.text.*;

/**
 * Console utilities.
 */
public class Console {

	/**
	 * Print a console [INFO] message.
	 *
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void info(String msg, Object...args) {
		System.out.println("[INFO] " + format(msg, args));
		System.out.flush();
	}

	/**
	 * Print a console [WARNING] message.
	 *
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void warning(String msg, Object...args) {
		System.err.println("[WARNING] " + format(msg, args));
		System.err.flush();
	}

	/**
	 * Print a console [ERROR] message.
	 *
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void error(String msg, Object...args) {
		System.err.println("[ERROR] " + format(msg, args));
		System.err.flush();
	}

	private static String format(String msg, Object...args) {
		if (args.length == 0)
			return msg;
		return MessageFormat.format(msg, args);
	}
}

==> apache-juneau-9.0.1-src.zip: juneau-9.0.1/juneau-doc/src/main/java/org/apache/juneau/doc/internal/Console.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.doc.internal;

import java.text.*;

/**
 * Console utilities.
 */
public class Console {

	/**
	 * Print a console [INFO] message.
	 *
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void info(String msg, Object...args) {
		System.out.println("[INFO] " + format(msg, args));
		System.out.flush();
	}

	/**
	 * Print a console [WARNING] message.
	 *
	 * @param position The source position of the tag.
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void warning(String msg, Object...args) {
		System.err.println("[WARNING] " + format(msg, args));  // NOT DEBUG
		System.err.flush();
	}

	/**
	 * Print a console [ERROR] message.
	 *
	 * @param position The source position of the tag.
	 * @param msg Message.
	 * @param args Message arguments.
	 */
	public static void error(String msg, Object...args) {
		System.err.println("[ERROR] " + format(msg, args));  // NOT DEBUG
		System.err.flush();
	}

	private static String format(String msg, Object...args) {
		if (args.length == 0)
			return msg;
		return MessageFormat.format(msg, args);
	}
}
